Learn R Programming

partycoloR (version 0.2.0)

partycoloR-package: partycoloR: Extract Party Colors and Logos from Wikipedia

Description

logo

Extract political party colors and logos from English Wikipedia party pages. Provides functions to scrape party infoboxes for color codes (HEX or HTML color names) and logo images. Includes integration with the Party Facts database for easy party lookups. Designed for political scientists and party researchers working with electoral and party data. For Party Facts, see Döring and Regel (2019) tools:::Rd_expr_doi("10.1177/1354068818820671") and Bederke, Döring, and Regel (2023) tools:::Rd_expr_doi("10.7910/DVN/TJINLQ").

Arguments

Author

Maintainer: Lukas Warode lukas.warode@gmx.de

See Also